Documentation
¶
Overview ¶
Package voc contains the vocabulary for Cloud resources and their properties that can be discovered using Clouditor
Index ¶
- Variables
- func ToStringInterface(r []interface{}) (s string, err error)
- func ToStruct(r IsCloudResource) (s *structpb.Value, err error)
- type ABAC
- type AccessRestriction
- type Account
- type ActivityLogging
- type AnomalyDetection
- type Application
- type ApplicationLogging
- type AtRestEncryption
- type Auditing
- type Authenticity
- type Authorization
- type AutomaticUpdates
- type Availability
- type Backup
- type BlockStorage
- type BootLogging
- type CICDService
- type CertificateBasedAuthentication
- type CloudSDK
- type Compute
- type Confidentiality
- type Container
- type ContainerImage
- type ContainerOrchestration
- type ContainerRegistry
- type CustomerKeyEncryption
- type DDoSProtection
- type DatabaseConnect
- type DatabaseOperation
- type DatabaseQuery
- type DatabaseService
- type DatabaseStorage
- type DeviceProvisioningService
- type DocumentDatabaseService
- type FileStorage
- type FileStorageService
- type Firewall
- type Framework
- type Function
- type Functionality
- type GeoLocation
- type HasHttpEndpoint
- type HttpClientLibrary
- type HttpEndpoint
- type HttpRequest
- type HttpRequestHandler
- type HttpServer
- type Identifiable
- type Identity
- type Image
- type Immutability
- type Integrity
- type IoT
- type IsAccessRestriction
- type IsAtRestEncryption
- type IsAuthenticity
- type IsAuthorization
- type IsCloudResource
- type IsCompute
- type IsNetwork
- type IsSecurityFeature
- type IsStorage
- type IsTransportEncryption
- type Job
- type KeyValueDatabaseService
- type L3Firewall
- type Library
- type LoadBalancer
- type LogOperation
- type Logger
- type Logging
- type LoggingService
- type MalwareProtection
- type ManagedKeyEncryption
- type MessagingHub
- type NetworkInterface
- type NetworkSecurityGroup
- type NetworkService
- type Networking
- type NoAuthentication
- type OSLogging
- type OTPBasedAuthentication
- type ObjectStorage
- type ObjectStorageRequest
- type ObjectStorageService
- type Operation
- type PasswordBasedAuthentication
- type PasswordPolicy
- type ProxiedEndpoint
- type RBAC
- type RelationalDatabaseService
- type Resource
- func (r *Resource) GetCreationTime() *time.Time
- func (r *Resource) GetID() ResourceID
- func (r *Resource) GetName() string
- func (r *Resource) GetRaw() string
- func (r *Resource) GetServiceID() string
- func (r *Resource) GetType() []string
- func (r *Resource) HasType(resourceType string) (ok bool)
- func (r *Resource) Related() []string
- func (r *Resource) SetServiceID(ID string)
- type ResourceGroup
- type ResourceID
- type ResourceLogging
- type RoleAssignment
- type SecurityFeature
- type SingleSignOn
- type Storage
- type StorageService
- type TokenBasedAuthentication
- type TranslationUnitDeclaration
- type TransportEncryption
- type VMImage
- type VirtualMachine
- type VirtualNetwork
- type VirtualSubNetwork
- type WebApplicationFirewall
- type Workflow
Constants ¶
This section is empty.
Variables ¶
var AccountType = []string{"Account", "Resource"}
var ApplicationType = []string{"Application", "Resource"}
var BlockStorageType = []string{"BlockStorage", "Storage", "Resource"}
var CICDServiceType = []string{"CI/CD Service", "Resource"}
var ComputeType = []string{"Compute", "Resource"}
var ContainerImageType = []string{"Container Image", "Image", "Resource"}
var ContainerOrchestrationType = []string{"ContainerOrchestration", "Resource"}
var ContainerRegistryType = []string{"ContainerRegistry", "Resource"}
var ContainerType = []string{"Container", "Compute", "Resource"}
var DatabaseServiceType = []string{"DatabaseService", "StorageService", "NetworkService", "Networking", "Resource"}
var DatabaseStorageType = []string{"DatabaseStorage", "Storage", "Resource"}
var DeviceProvisioningServiceType = []string{"DeviceProvisioningService", "IoT", "Resource"}
var DocumentDatabaseServiceType = []string{"DocumentDatabaseService", "DatabaseService", "StorageService", "NetworkService", "Networking", "Resource"}
var (
ErrConvertingStructToString = errors.New("error converting struct to string")
)
var FileStorageServiceType = []string{"FileStorageService", "StorageService", "NetworkService", "Networking", "Resource"}
var FileStorageType = []string{"FileStorage", "Storage", "Resource"}
var FunctionType = []string{"Function", "Compute", "Resource"}
var IdentifiableType = []string{"Identifiable", "Resource"}
var IdentityType = []string{"Identity", "Identifiable", "Resource"}
var ImageType = []string{"Image", "Resource"}
var IoTType = []string{"IoT", "Resource"}
var JobType = []string{"Job", "CI/CD Service", "Resource"}
var KeyValueDatabaseServiceType = []string{"KeyValueDatabaseService", "DatabaseService", "StorageService", "NetworkService", "Networking", "Resource"}
var LibraryType = []string{"Library", "Resource"}
var LoadBalancerType = []string{"LoadBalancer", "NetworkService", "Networking", "Resource"}
var LoggingServiceType = []string{"LoggingService", "NetworkService", "Networking", "Resource"}
var MessagingHubType = []string{"MessagingHub", "IoT", "Resource"}
var NetworkInterfaceType = []string{"NetworkInterface", "Networking", "Resource"}
var NetworkSecurityGroupType = []string{"NetworkSecurityGroup", "Networking", "Resource"}
var NetworkServiceType = []string{"NetworkService", "Networking", "Resource"}
var NetworkingType = []string{"Networking", "Resource"}
var ObjectStorageServiceType = []string{"ObjectStorageService", "StorageService", "NetworkService", "Networking", "Resource"}
var ObjectStorageType = []string{"ObjectStorage", "Storage", "Resource"}
var PasswordPolicyType = []string{"PasswordPolicy", "Resource"}
var RelationalDatabaseServiceType = []string{"RelationalDatabaseService", "DatabaseService", "StorageService", "NetworkService", "Networking", "Resource"}
var RoleAssignmentType = []string{"RoleAssignment", "Identifiable", "Resource"}
var StorageServiceType = []string{"StorageService", "NetworkService", "Networking", "Resource"}
var StorageType = []string{"Storage", "Resource"}
var TranslationUnitDeclarationType = []string{"TranslationUnitDeclaration", "Resource"}
var VMImageType = []string{"VM Image", "Image", "Resource"}
var VirtualMachineType = []string{"VirtualMachine", "Compute", "Resource"}
var VirtualNetworkType = []string{"VirtualNetwork", "Networking", "Resource"}
var VirtualSubNetworkType = []string{"VirtualSubNetwork", "Networking", "Resource"}
var WorkflowType = []string{"Workflow", "CI/CD Service", "Resource"}
Functions ¶
func ToStringInterface ¶ added in v1.9.0
ToStringInterface returns a string representation of the input
Types ¶
type ABAC ¶ added in v1.3.5
type ABAC struct {
*Authorization
}
type AccessRestriction ¶ added in v1.3.3
type AccessRestriction struct {
*Authorization
}
func (*AccessRestriction) Type ¶ added in v1.6.2
func (*AccessRestriction) Type() string
type Account ¶ added in v1.3.5
type Account struct {
*Resource
}
Account is an entity in our Cloud ontology. This represents the cloud account as a whole, e.g., an Azure subscription.
type ActivityLogging ¶ added in v1.4.0
type ActivityLogging struct {
*Logging
}
type AnomalyDetection ¶ added in v1.3.7
type AnomalyDetection struct {
*Auditing
ApplicationLogging *ApplicationLogging `json:"applicationLogging"`
Enabled bool `json:"enabled"`
}
AnomalyDetection is an entity in our Cloud ontology. analyzes the activity of a NetworkService (which includes DatabaseServices)
type Application ¶ added in v1.3.5
type Application struct {
*Resource
Functionalities []*Functionality `json:"functionalities"`
Compute []ResourceID `json:"compute"`
ProgrammingLanguage string `json:"programmingLanguage"`
TranslationUnits []ResourceID `json:"translationUnits"`
Dependencies []ResourceID `json:"dependencies"`
}
Application is an entity in our Cloud ontology. This encapsulates the whole (source) code of an application.
func (Application) Related ¶ added in v1.10.0
func (a Application) Related() []string
type ApplicationLogging ¶ added in v1.4.0
type ApplicationLogging struct {
*Logging
}
type AtRestEncryption ¶
type AtRestEncryption struct {
*Confidentiality
Algorithm string `json:"algorithm"`
Enabled bool `json:"enabled"`
}
func (*AtRestEncryption) IsEnabled ¶ added in v1.6.2
func (a *AtRestEncryption) IsEnabled() bool
func (*AtRestEncryption) Type ¶ added in v1.6.2
func (*AtRestEncryption) Type() string
type Auditing ¶ added in v1.3.5
type Auditing struct {
*SecurityFeature
}
type Authenticity ¶ added in v1.3.5
type Authenticity struct {
*SecurityFeature
}
type Authorization ¶ added in v1.3.5
type Authorization struct {
*SecurityFeature
}
type AutomaticUpdates ¶ added in v1.3.7
type AutomaticUpdates struct {
*Integrity
Enabled bool `json:"enabled"`
SecurityOnly bool `json:"securityOnly"`
// The interval refers to the update interval in days.
Interval time.Duration `json:"interval"`
}
AutomaticUpdates is an entity in our Cloud ontology. This feature is, e.g., available on some VM services to automatically update their software. It ensures that a resource is protected from tampering with its state.
type Availability ¶ added in v1.3.5
type Availability struct {
*SecurityFeature
}
type Backup ¶ added in v1.3.5
type Backup struct {
*Availability
TransportEncryption IsTransportEncryption `json:"transportEncryption"`
Storage ResourceID `json:"storage"`
Enabled bool `json:"enabled"`
RetentionPeriod time.Duration `json:"retentionPeriod"`
// The interval refers to the update interval in days.
Interval time.Duration `json:"interval"`
}
Backup is an entity in our Cloud ontology. RetentionPeriod in hours
type BlockStorage ¶ added in v1.3.5
type BlockStorage struct {
*Storage
}
type BootLogging ¶ added in v1.4.0
type BootLogging struct {
*Logging
}
type CICDService ¶ added in v1.3.5
type CICDService struct {
*Resource
}
type CertificateBasedAuthentication ¶ added in v1.3.5
type CertificateBasedAuthentication struct {
*Authenticity
Enabled bool `json:"enabled"`
}
func (*CertificateBasedAuthentication) Type ¶ added in v1.6.2
func (*CertificateBasedAuthentication) Type() string
type Compute ¶ added in v1.3.5
type Compute struct {
*Resource
NetworkInterfaces []ResourceID `json:"networkInterfaces"`
ResourceLogging *ResourceLogging `json:"resourceLogging"`
}
type Confidentiality ¶ added in v1.3.5
type Confidentiality struct {
*SecurityFeature
}
type Container ¶ added in v1.3.5
type Container struct {
*Compute
Image ResourceID `json:"image"`
}
type ContainerImage ¶ added in v1.3.5
type ContainerImage struct {
*Image
}
type ContainerOrchestration ¶ added in v1.3.5
type ContainerOrchestration struct {
*Resource
ResourceLogging *ResourceLogging `json:"resourceLogging"`
Containers []ResourceID `json:"containers"`
ManagementUrl string `json:"managementUrl"`
}
type ContainerRegistry ¶ added in v1.3.5
type ContainerRegistry struct {
*Resource
}
type CustomerKeyEncryption ¶ added in v1.3.5
type CustomerKeyEncryption struct {
*AtRestEncryption
KeyUrl string `json:"keyUrl"`
}
func (*CustomerKeyEncryption) Type ¶ added in v1.6.2
func (*CustomerKeyEncryption) Type() string
type DDoSProtection ¶ added in v1.3.5
type DDoSProtection struct {
*Availability
}
type DatabaseConnect ¶ added in v1.3.5
type DatabaseConnect struct {
*DatabaseOperation
}
type DatabaseOperation ¶ added in v1.3.5
type DatabaseOperation struct {
*Operation
Storage []ResourceID `json:"storage"`
DatabaseService []ResourceID `json:"databaseService"`
Calls []string `json:"calls"`
}
type DatabaseQuery ¶ added in v1.3.5
type DatabaseQuery struct {
*DatabaseOperation
Modify bool `json:"modify"`
}
type DatabaseService ¶ added in v1.3.5
type DatabaseService struct {
*StorageService
AnomalyDetection *AnomalyDetection `json:"anomalyDetection"`
}
DatabaseService is an entity in our Cloud ontology. This class represents a database service. For example, a postgres SQL server would be modelled as a database service (with a host and IP) and the individual tables or collections would be modelled as a DatabaseStorage entity.
type DatabaseStorage ¶ added in v1.3.7
type DatabaseStorage struct {
*Storage
Parent []ResourceID `json:"parent"`
}
DatabaseStorage is an entity in our Cloud ontology. describes the actual database or a table in a database
type DeviceProvisioningService ¶ added in v1.3.5
type DeviceProvisioningService struct {
*IoT
}
type DocumentDatabaseService ¶ added in v1.3.5
type DocumentDatabaseService struct {
*DatabaseService
}
type FileStorage ¶ added in v1.3.5
type FileStorageService ¶ added in v1.9.0
type FileStorageService struct {
*StorageService
HttpEndpoint *HttpEndpoint `json:"httpEndpoint"`
}
FileStorageService is an entity in our Cloud ontology. An file storage service represents the network service that is used to access a list of file storage shares. The storage itself is modelled as a FileStorage. The service has an http endpoint.
type Firewall ¶ added in v1.8.0
type Firewall struct {
*AccessRestriction
}
type Functionality ¶ added in v1.3.5
type Functionality struct {
}
type GeoLocation ¶
type GeoLocation struct {
*Availability
Region string `json:"region"`
}
type HasHttpEndpoint ¶
type HasHttpEndpoint interface {
GetHttpEndpoint() *HttpEndpoint
}
type HttpClientLibrary ¶ added in v1.3.5
type HttpClientLibrary struct {
*Framework
}
type HttpEndpoint ¶
type HttpEndpoint struct {
*Functionality
Authenticity IsAuthenticity `json:"authenticity"`
TransportEncryption *TransportEncryption `json:"transportEncryption"`
Url string `json:"url"`
Method string `json:"method"`
Handler string `json:"handler"`
Path string `json:"path"`
}
HttpEndpoint is an entity in our Cloud ontology. Via the Authenticity relationship, the access type can be specified, e.g. public access (no authentication), password-based, etc.
type HttpRequest ¶ added in v1.3.5
type HttpRequest struct {
*Operation
HttpEndpoint *HttpEndpoint `json:"httpEndpoint"`
Call string `json:"call"`
ReqBody string `json:"reqBody"`
}
type HttpRequestHandler ¶ added in v1.3.5
type HttpRequestHandler struct {
*Functionality
Application *Application `json:"application"`
HttpEndpoints []*HttpEndpoint `json:"httpEndpoints"`
Path string `json:"path"`
}
type HttpServer ¶ added in v1.3.5
type HttpServer struct {
*Framework
HttpRequestHandler *HttpRequestHandler `json:"httpRequestHandler"`
}
type Identifiable ¶ added in v1.6.2
type Identifiable struct {
*Resource
Authenticity IsAuthenticity `json:"authenticity"`
Authorization IsAuthorization `json:"authorization"`
Activated bool `json:"activated"`
}
type Identity ¶ added in v1.3.5
type Identity struct {
*Identifiable
Authenticities []IsAuthenticity `json:"authenticities"`
Privileged bool `json:"privileged"`
LastActivity time.Time `json:"lastActivity"`
DisablePasswordPolicy bool `json:"disablePasswordPolicy"`
}
type Image ¶ added in v1.3.5
type Image struct {
*Resource
Application *Application `json:"application"`
}
type Immutability ¶ added in v1.3.5
type Integrity ¶ added in v1.3.5
type Integrity struct {
*SecurityFeature
}
type IsAccessRestriction ¶ added in v1.8.0
type IsAccessRestriction interface {
IsSecurityFeature
// contains filtered or unexported methods
}
type IsAtRestEncryption ¶ added in v1.6.2
type IsAtRestEncryption interface {
IsSecurityFeature
IsEnabled() bool
// contains filtered or unexported methods
}
type IsAuthenticity ¶ added in v1.6.2
type IsAuthenticity interface {
IsSecurityFeature
// contains filtered or unexported methods
}
type IsAuthorization ¶ added in v1.6.2
type IsAuthorization interface {
IsSecurityFeature
// contains filtered or unexported methods
}
type IsCloudResource ¶ added in v1.3.5
type IsCompute ¶ added in v1.3.3
type IsCompute interface {
IsCloudResource
}
type IsNetwork ¶ added in v1.3.5
type IsNetwork interface {
IsCloudResource
}
type IsSecurityFeature ¶ added in v1.6.2
type IsSecurityFeature interface {
Type() string
}
type IsStorage ¶
type IsStorage interface {
IsCloudResource
IsAtRestEncryption
}
type IsTransportEncryption ¶ added in v1.9.0
type IsTransportEncryption interface {
IsSecurityFeature
IsEnabled() bool
// contains filtered or unexported methods
}
type Job ¶ added in v1.3.5
type Job struct {
*CICDService
}
type KeyValueDatabaseService ¶ added in v1.3.5
type KeyValueDatabaseService struct {
*DatabaseService
}
type L3Firewall ¶ added in v1.3.7
type Library ¶ added in v1.10.0
type Library struct {
*Resource
Functionalities []*Functionality `json:"functionalities"`
ProgrammingLanguage string `json:"programmingLanguage"`
TranslationUnits []ResourceID `json:"translationUnits"`
Dependencies []ResourceID `json:"dependencies"`
GroupID string `json:"groupId"`
ArtifactID string `json:"artifactId"`
Version string `json:"version"`
DependencyType string `json:"dependencyType"` // DependencyType denotes which type of dependency it is, e.g., maven or npm
URL string `json:"url"`
}
Library is an entity in our Cloud ontology. It encapsulates the (source) code of a library, similar to an application. TODO(oxisto): Add this to the ontology and auto-generate it
type LoadBalancer ¶ added in v1.3.5
type LoadBalancer struct {
*NetworkService
AccessRestriction IsAccessRestriction `json:"accessRestriction"`
HttpEndpoints []*HttpEndpoint `json:"httpEndpoints"`
NetworkServices []ResourceID `json:"networkServices"`
Url string `json:"url"`
}
LoadBalancer is an entity in our Cloud ontology. A Load Balancer may have multiple access restriction features, e.g. a L3 firewall and a WAF
type LogOperation ¶ added in v1.4.0
type LogOperation struct {
*Operation
Logging *Logging `json:"logging"`
Call string `json:"call"`
Value string `json:"value"`
}
LogOperation is an entity in our Cloud ontology. A LogOperation is used by an application
type Logging ¶ added in v1.3.5
type LoggingService ¶ added in v1.4.0
type LoggingService struct {
*NetworkService
Storage []ResourceID `json:"storage"`
}
LoggingService is an entity in our Cloud ontology. A logging-as-a-service offering, e.g. for analyzing logs; has a Storage resource that stores the logs
func (LoggingService) Related ¶ added in v1.6.2
func (l LoggingService) Related() []string
Related returns related resources for the logging service, e.g., its storage.
type MalwareProtection ¶ added in v1.3.7
type MalwareProtection struct {
*Auditing
ApplicationLogging *ApplicationLogging `json:"applicationLogging"`
DaysSinceActive time.Duration `json:"daysSinceActive"`
NumberOfThreatsFound int `json:"numberOfThreatsFound"`
Enabled bool `json:"enabled"`
}
MalwareProtection is an entity in our Cloud ontology. analyzes the activity within a Compute resource
type ManagedKeyEncryption ¶ added in v1.3.5
type ManagedKeyEncryption struct {
*AtRestEncryption
}
func (*ManagedKeyEncryption) Type ¶ added in v1.6.2
func (*ManagedKeyEncryption) Type() string
type MessagingHub ¶ added in v1.3.5
type MessagingHub struct {
*IoT
}
type NetworkInterface ¶ added in v1.3.5
type NetworkInterface struct {
*Networking
AccessRestriction IsAccessRestriction `json:"accessRestriction"`
NetworkService ResourceID `json:"networkService"`
}
type NetworkSecurityGroup ¶ added in v1.3.5
type NetworkSecurityGroup struct {
*Networking
}
type NetworkService ¶ added in v1.3.5
type NetworkService struct {
*Networking
Authenticity IsAuthenticity `json:"authenticity"`
Compute ResourceID `json:"compute"`
TransportEncryption *TransportEncryption `json:"transportEncryption"`
Ips []string `json:"ips"`
Ports []uint16 `json:"ports"`
}
NetworkService is an entity in our Cloud ontology. A NetworkService is an application (on the network layer) running on a Compute resource. It provides access to a resource
type Networking ¶ added in v1.3.5
type Networking struct {
*Resource
}
type NoAuthentication ¶ added in v1.3.5
type NoAuthentication struct {
*Authenticity
}
func (*NoAuthentication) Type ¶ added in v1.6.2
func (*NoAuthentication) Type() string
type OTPBasedAuthentication ¶ added in v1.3.5
type OTPBasedAuthentication struct {
*Authenticity
Activated bool `json:"activated"`
}
func (*OTPBasedAuthentication) Type ¶ added in v1.6.2
func (*OTPBasedAuthentication) Type() string
type ObjectStorage ¶ added in v1.3.5
type ObjectStorageRequest ¶ added in v1.3.5
type ObjectStorageRequest struct {
*Operation
ObjectStorage []ResourceID `json:"objectStorage"`
Source string `json:"source"`
Type string `json:"type"`
}
type ObjectStorageService ¶ added in v1.6.2
type ObjectStorageService struct {
*StorageService
HttpEndpoint *HttpEndpoint `json:"httpEndpoint"`
}
ObjectStorageService is an entity in our Cloud ontology. An object storage service represents the network service that is used to access a list of object storage containers. The storage itself is modelled as a ObjectStorage. The service has an http endpoint.
type Operation ¶ added in v1.4.0
type Operation struct {
*Functionality
}
type PasswordBasedAuthentication ¶ added in v1.3.5
type PasswordBasedAuthentication struct {
*Authenticity
Activated bool `json:"activated"`
}
func (*PasswordBasedAuthentication) Type ¶ added in v1.6.2
func (*PasswordBasedAuthentication) Type() string
type PasswordPolicy ¶ added in v1.6.2
type PasswordPolicy struct {
*Resource
}
type ProxiedEndpoint ¶ added in v1.3.5
type ProxiedEndpoint struct {
*HttpEndpoint
ProxyTarget *HttpEndpoint `json:"proxyTarget"`
}
ProxiedEndpoint is an entity in our Cloud ontology. An HTTP endpoint, that is routed through a (reverse) proxy, e.g. a load balancer.
type RBAC ¶ added in v1.3.5
type RBAC struct {
*Authorization
// see Privacy Smells: Detecting Privacy Problems in Cloud Architectures (2020)
MixedDuties float32 `json:"mixedDuties"`
// see Privacy Smells: Detecting Privacy Problems in Cloud Architectures (2020)
BroadAssignments float32 `json:"broadAssignments"`
}
type RelationalDatabaseService ¶ added in v1.3.5
type RelationalDatabaseService struct {
*DatabaseService
}
type Resource ¶
type Resource struct {
ID ResourceID `json:"id"`
// ServiceID contains the ID of the cloud service to which this resource belongs. When creating new resources using
// the NewResource function of the discovery API, this gets filled automatically.
ServiceID string `json:"serviceId"`
Name string `json:"name"`
CreationTime int64 `json:"creationTime"` // is set to 0 if no creation time is available
// The resource type. It is an array, because a type can be derived from another
Type []string `json:"type"`
GeoLocation GeoLocation `json:"geoLocation"`
Labels map[string]string `json:"labels"`
Raw string `json:"raw"`
Parent ResourceID `json:"parent"`
}
Resource file from Ontology currently not used. How do we merge this file with the 'Resource Ontology file'
func (*Resource) GetCreationTime ¶
func (*Resource) GetID ¶
func (r *Resource) GetID() ResourceID
func (*Resource) GetServiceID ¶ added in v1.5.2
func (*Resource) HasType ¶ added in v1.4.0
HasType checks whether the resource has the particular resourceType
func (*Resource) SetServiceID ¶ added in v1.6.2
type ResourceGroup ¶ added in v1.10.0
type ResourceGroup struct {
*Resource
}
type ResourceID ¶ added in v1.3.5
type ResourceID string
type ResourceLogging ¶ added in v1.3.5
type ResourceLogging struct {
*Logging
}
type RoleAssignment ¶ added in v1.3.5
type RoleAssignment struct {
*Identifiable
}
type SecurityFeature ¶ added in v1.3.5
type SecurityFeature struct {
}
type SingleSignOn ¶ added in v1.3.5
type SingleSignOn struct {
*Authenticity
Enabled bool `json:"enabled"`
}
func (*SingleSignOn) Type ¶ added in v1.6.2
func (*SingleSignOn) Type() string
type Storage ¶ added in v1.3.5
type Storage struct {
*Resource
AtRestEncryption IsAtRestEncryption `json:"atRestEncryption"`
Backups []*Backup `json:"backups"`
Immutability *Immutability `json:"immutability"`
ResourceLogging *ResourceLogging `json:"resourceLogging"`
}
type StorageService ¶ added in v1.4.0
type StorageService struct {
*NetworkService
Storage []ResourceID `json:"storage"`
}
StorageService is an entity in our Cloud ontology. This entity represents a network-based service that can be used to access a particular storage backend. It has multiple subclasses, e.g., for databases or object stores. It has a list of storage resources associated to it.
func (StorageService) Related ¶ added in v1.10.0
func (s StorageService) Related() []string
type TokenBasedAuthentication ¶ added in v1.6.2
type TokenBasedAuthentication struct {
*Authenticity
Enforced bool `json:"enforced"`
Enabled bool `json:"enabled"`
}
func (*TokenBasedAuthentication) Type ¶ added in v1.6.2
func (*TokenBasedAuthentication) Type() string
type TranslationUnitDeclaration ¶ added in v1.10.0
TranslationUnitDeclaration is an entity in our Cloud ontology. It refers to https://fraunhofer-aisec.github.io/cpg/CPG/specs/graph/#translationunitdeclaration
type TransportEncryption ¶
type TransportEncryption struct {
*Confidentiality
Enforced bool `json:"enforced"`
Enabled bool `json:"enabled"`
TlsVersion string `json:"tlsVersion"`
Algorithm string `json:"algorithm"`
}
TransportEncryption is an entity in our Cloud ontology. enabled means the resource _can_ be reached via https, while enforced means it _can only_ be reached via https (or http traffic is redirected)
func (*TransportEncryption) IsEnabled ¶ added in v1.9.0
func (a *TransportEncryption) IsEnabled() bool
func (*TransportEncryption) Type ¶ added in v1.6.2
func (*TransportEncryption) Type() string
type VirtualMachine ¶ added in v1.3.5
type VirtualMachine struct {
*Compute
BlockStorage []ResourceID `json:"blockStorage"`
AutomaticUpdates *AutomaticUpdates `json:"automaticUpdates"`
BootLogging *BootLogging `json:"bootLogging"`
MalwareProtection *MalwareProtection `json:"malwareProtection"`
OsLogging *OSLogging `json:"osLogging"`
ActivityLogging *ActivityLogging `json:"activityLogging"`
}
func (VirtualMachine) Related ¶ added in v1.6.2
func (v VirtualMachine) Related() []string
Related returns related resources for the virtual machine, e.g., its attached storage and network interfaces.
type VirtualNetwork ¶ added in v1.3.5
type VirtualNetwork struct {
*Networking
}
type VirtualSubNetwork ¶ added in v1.3.5
type VirtualSubNetwork struct {
*Networking
}
type WebApplicationFirewall ¶ added in v1.3.7
WebApplicationFirewall is an entity in our Cloud ontology. A WAF is a L7 firewall that includes L3 capabilities
type Workflow ¶ added in v1.3.5
type Workflow struct {
*CICDService
}
Source Files
¶
- abac.go
- access_restriction.go
- account.go
- activity_logging.go
- anomaly_detection.go
- application.go
- application_logging.go
- at_rest_encryption.go
- auditing.go
- authenticity.go
- authorization.go
- automatic_updates.go
- availability.go
- backup.go
- block_storage.go
- boot_logging.go
- certificate_based_authentication.go
- cicd_service.go
- cloud_sdk.go
- compute.go
- confidentiality.go
- container.go
- container_image.go
- container_orchestration.go
- container_registry.go
- customer_key_encryption.go
- d_do_s_protection.go
- database_connect.go
- database_operation.go
- database_query.go
- database_service.go
- database_storage.go
- device_provisioning_service.go
- document_database_service.go
- file_storage.go
- file_storage_service.go
- firewall.go
- framework.go
- function.go
- functionality.go
- geo_location.go
- http_client_library.go
- http_endpoint.go
- http_request.go
- http_request_handler.go
- http_server.go
- identifiable.go
- identity.go
- image.go
- immutability.go
- integrity.go
- io_t.go
- job.go
- key_value_database_service.go
- l3_firewall.go
- library.go
- load_balancer.go
- log_operation.go
- logger.go
- logging.go
- logging_service.go
- malware_protection.go
- managed_key_encryption.go
- messaging_hub.go
- network_interface.go
- network_security_group.go
- network_service.go
- networking.go
- no_authentication.go
- object_storage.go
- object_storage_request.go
- object_storage_service.go
- operation.go
- os_logging.go
- otp_based_authentication.go
- password_based_authentication.go
- password_policy.go
- proxied_endpoint.go
- rbac.go
- related.go
- relational_database_service.go
- resource_group.go
- resource_logging.go
- role_assignment.go
- security_feature.go
- single_sign_on.go
- storage.go
- storage_service.go
- token_based_authentication.go
- translation_unit_declaration.go
- transport_encryption.go
- virtual_machine.go
- virtual_network.go
- virtual_sub_network.go
- vm_image.go
- voc.go
- web_application_firewall.go
- workflow.go